.. DataRobot Python Package documentation master file, created by
   sphinx-quickstart on Mon Mar 16 10:50:19 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Administration
========================

The administration section provides details for users and administrators.

.. toctree::
   :maxdepth: 2

   credentials.rst
   sharing.rst
